@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2016-2021 Jolla Ltd.
- * Copyright (C) 2016-2021 Slava Monich <slava.monich@jolla.com>
+ * Copyright (C) 2016-2022 Jolla Ltd.
+ * Copyright (C) 2016-2022 Slava Monich <slava.monich@jolla.com>
  *
  * You may use this file under the terms of BSD license as follows:
  *
@@ -148,6 +148,10 @@ gutil_memdup(
     const void* ptr,
     gsize size); /* Since 1.0.52 */
 
+gsize
+gutil_strlen0(
+    const char* str); /* Since 1.0.62 */
+
 gsize
 gutil_range_init_with_bytes(
     GUtilRange* range,
